summaryrefslogtreecommitdiff
path: root/src/socket_base.hpp
diff options
context:
space:
mode:
authorMartin Sustrik <sustrik@250bpm.com>2012-02-16 10:10:49 +0900
committerMartin Sustrik <sustrik@250bpm.com>2012-02-16 10:10:49 +0900
commit50f225a04422abf64545f5eb36592d8c990b0ae4 (patch)
tree1ad0396c3f32b4e89f80d4abdbf0d9ced6a1e55c /src/socket_base.hpp
parente5e9852181947a9c41db9ff3c47e94d66a933161 (diff)
poller_base_t renamed to io_thread_t
Signed-off-by: Martin Sustrik <sustrik@250bpm.com>
Diffstat (limited to 'src/socket_base.hpp')
-rw-r--r--src/socket_base.hpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/socket_base.hpp b/src/socket_base.hpp
index 8b9a948..dd1fee7 100644
--- a/src/socket_base.hpp
+++ b/src/socket_base.hpp
@@ -28,7 +28,7 @@
#include "own.hpp"
#include "array.hpp"
#include "stdint.hpp"
-#include "poller_base.hpp"
+#include "io_thread.hpp"
#include "atomic_counter.hpp"
#include "mailbox.hpp"
#include "stdint.hpp"
@@ -83,12 +83,12 @@ namespace xs
bool has_in ();
bool has_out ();
- // Using this function reaper thread ask the socket to regiter with
- // its poller.
- void start_reaping (poller_base_t *poller_);
+ // Using this function reaper thread asks the socket to regiter with
+ // its I/O thread.
+ void start_reaping (io_thread_t *io_thread_);
// i_poll_events implementation. This interface is used when socket
// is handled by the poller in the reaper thread.
void in_event (fd_t fd_);
void out_event (fd_t fd_);
void timer_event (handle_t handle_);
@@ -188,8 +188,8 @@ namespace xs
typedef array_t <pipe_t, 3> pipes_t;
pipes_t pipes;
- // Reaper's poller and handle of this socket within it.
- poller_base_t *poller;
+ // Reaper's io_thread and handle of this socket within it.
+ io_thread_t *io_thread;
handle_t handle;
// Timestamp of when commands were processed the last time.
@@ -83,12 +83,12 @@ namespace xs
// i_poll_events implementation. This interface is used when socket
- // is handled by the poller in the reaper thread.
+ // is handled by the io_thread in the reaper thread.
void in_event (fd_t fd_);
void out_event (fd_t fd_);